## Carbon2-Server

Collect news related to carbon neutrality and carbon peak emission

## Install

```
   pip install carbon2-server
```

## License
The `carbon2-server` toolkit is provided by [Donghua Chen](https://github.com/dhchenx) with MIT License.

